@@ -4,7 +4,7 @@
 import abc
 from typing import List
 from .base_team import BaseTeam
-from .base_factory import BaseFactory
+from .base_workplace import BaseWorkplace
 from .base_worker import BaseWorker, BaseWorkerState
 from .base_facility import BaseFacility, BaseFacilityState
 import plotly.figure_factory as ff
@@ -18,16 +18,16 @@ import warnings
 class BaseOrganization(object, metaclass=abc.ABCMeta):
     """BaseOrganization
     BaseOrganization class for expressing organization in target project.
-    BaseOrganization is consist of multiple BaseTeam and BaseFactory.
+    BaseOrganization is consist of multiple BaseTeam and BaseWorkplace.
     This class will be used as template.
 
     Args:
         team_list (List[BaseTeam]):
             Basic parameter.
             List of BaseTeam in this organization.
-        factory_list (List[BaseFactory], optional):
+        workplace_list (List[BaseWorkplace], optional):
             Basic parameter.
-            List of BaseFactory in this organization.
+            List of BaseWorkplace in this organization.
             Default to None -> []
         cost_list (List[float], optional):
             Basic variable.
@@ -39,7 +39,7 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
         self,
         # Basic parameters
         team_list: List[BaseTeam],
-        factory_list=None,
+        workplace_list=None,
         # Basic variables
         cost_list=None,
     ):
@@ -48,7 +48,7 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
         # --
         # Basic parameter
         self.team_list = team_list
-        self.factory_list = factory_list if factory_list is not None else []
+        self.workplace_list = workplace_list if workplace_list is not None else []
         # --
         # Advanced parameter for customized simulation
 
@@ -82,7 +82,7 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
         dict_json_data.update(
             type="BaseOrganization",
             team_list=[t.export_dict_json_data() for t in self.team_list],
-            factory_list=[t.export_dict_json_data() for t in self.factory_list],
+            workplace_list=[t.export_dict_json_data() for t in self.workplace_list],
             cost_list=self.cost_list,
         )
         return dict_json_data
@@ -129,15 +129,15 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
                 )
             )
 
-        self.factory_list = []
-        j_list = json_data["factory_list"]
+        self.workplace_list = []
+        j_list = json_data["workplace_list"]
         for j in j_list:
             facility_list = []
             for w in j["facility_list"]:
                 facility = BaseFacility(
                     name=w["name"],
                     ID=w["ID"],
-                    factory_id=w["factory_id"],
+                    workplace_id=w["workplace_id"],
                     cost_per_time=w["cost_per_time"],
                     solo_working=w["solo_working"],
                     workamount_skill_mean_map=w["workamount_skill_mean_map"],
@@ -152,13 +152,13 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
                     assigned_task_id_record=w["assigned_task_id_record"],
                 )
                 facility_list.append(facility)
-            self.factory_list.append(
-                BaseFactory(
+            self.workplace_list.append(
+                BaseWorkplace(
                     name=j["name"],
                     ID=j["ID"],
                     facility_list=facility_list,
                     targeted_task_list=j["targeted_task_list"],
-                    parent_factory=j["parent_factory"],
+                    parent_workplace=j["parent_workplace"],
                     max_space_size=j["max_space_size"],
                     cost_list=j["cost_list"],
                     placed_component_list=j["placed_component_list"],
@@ -221,97 +221,97 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
             team_list = list(filter(lambda x: x.cost_list == cost_list, team_list))
         return team_list
 
-    def get_factory_list(
+    def get_workplace_list(
         self,
         name=None,
         ID=None,
         facility_list=None,
         targeted_task_list=None,
-        parent_factory=None,
+        parent_workplace=None,
         max_space_size=None,
         cost_list=None,
         placed_component_list=None,
         placed_component_id_record=None,
     ):
         """
-        Get factory list by using search conditions related to BaseTeam parameter.
-        If there is no searching condition, this function returns all self.factory_list
+        Get workplace list by using search conditions related to BaseTeam parameter.
+        If there is no searching condition, this function returns all self.workplace_list
 
         Args:
             name (str, optional):
-                Target factory name.
+                Target workplace name.
                 Defaults to None.
             ID (str, optional):
-                Target factory ID.
+                Target workplace ID.
                 Defaults to None.
             facility_list (List[BaseFacility], optional):
-                Target factory facility_list.
+                Target workplace facility_list.
                 Defaults to None.
             targeted_task_list (List[BaseTask], optional):
-                Target factory targeted_task_list.
+                Target workplace targeted_task_list.
                 Defaults to None.
-            parent_factory (BaseFactory, optional):
-                Target factory parent_factory.
+            parent_workplace (BaseWorkplace, optional):
+                Target workplace parent_workplace.
                 Defaults to None.
             max_space_size (float, optional):
-                Target factory max_space_size.
+                Target workplace max_space_size.
                 Defaults to None.
             placed_component_list (List[BaseComponent], optional):
-                Target factory placed_component_list.
+                Target workplace placed_component_list.
                 Defaults to None.
             placed_component_id_record(List[List[str]], optional):
-                Target factory placed_component_id_record.
+                Target workplace placed_component_id_record.
                 Defaults to None.
             cost_list (List[float], optional):
-                Target factory cost_list.
+                Target workplace cost_list.
                 Defaults to None.
 
         Returns:
-            List[BaseFactory]: List of BaseFactory.
+            List[BaseWorkplace]: List of BaseWorkplace.
         """
-        factory_list = self.factory_list
+        workplace_list = self.workplace_list
         if name is not None:
-            factory_list = list(filter(lambda x: x.name == name, factory_list))
+            workplace_list = list(filter(lambda x: x.name == name, workplace_list))
         if ID is not None:
-            factory_list = list(filter(lambda x: x.ID == ID, factory_list))
+            workplace_list = list(filter(lambda x: x.ID == ID, workplace_list))
         if facility_list is not None:
-            factory_list = list(
-                filter(lambda x: x.facility_list == facility_list, factory_list)
+            workplace_list = list(
+                filter(lambda x: x.facility_list == facility_list, workplace_list)
             )
         if targeted_task_list is not None:
-            factory_list = list(
+            workplace_list = list(
                 filter(
-                    lambda x: x.targeted_task_list == targeted_task_list, factory_list
+                    lambda x: x.targeted_task_list == targeted_task_list, workplace_list
                 )
             )
-        if parent_factory is not None:
-            factory_list = list(
-                filter(lambda x: x.parent_factory == parent_factory, factory_list)
+        if parent_workplace is not None:
+            workplace_list = list(
+                filter(lambda x: x.parent_workplace == parent_workplace, workplace_list)
             )
         if max_space_size is not None:
-            factory_list = list(
-                filter(lambda x: x.max_space_size == max_space_size, factory_list)
+            workplace_list = list(
+                filter(lambda x: x.max_space_size == max_space_size, workplace_list)
             )
         if placed_component_list is not None:
-            factory_list = list(
+            workplace_list = list(
                 filter(
                     lambda x: x.placed_component_list == placed_component_list,
-                    factory_list,
+                    workplace_list,
                 )
             )
         if placed_component_id_record is not None:
-            factory_list = list(
+            workplace_list = list(
                 filter(
                     lambda x: x.placed_component_id_record
                     == placed_component_id_record,
-                    factory_list,
+                    workplace_list,
                 )
             )
         if cost_list is not None:
-            factory_list = list(
-                filter(lambda x: x.cost_list == cost_list, factory_list)
+            workplace_list = list(
+                filter(lambda x: x.cost_list == cost_list, workplace_list)
             )
-        return factory_list
+        return workplace_list
 
     def get_worker_list(
         self,
@@ -339,8 +339,8 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
             ID (str, optional):
                 Target worker ID.
                 Defaults to None.
-            factory_id (str, optional):
-                Target worker factory_id.
+            workplace_id (str, optional):
+                Target worker workplace_id.
                 Defaults to None.
             cost_per_time (float, optional):
                 Target worker cost_per_time.
@@ -395,7 +395,7 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
         self,
         name=None,
         ID=None,
-        factory_id=None,
+        workplace_id=None,
         cost_per_time=None,
         solo_working=None,
         workamount_skill_mean_map=None,
@@ -407,7 +407,7 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
     ):
         """
         Get facility list by using search conditions related to BaseFacility parameter.
-        This method just executes BaseTeam.get_facility_list() in self.factory_list.
+        This method just executes BaseTeam.get_facility_list() in self.workplace_list.
 
         Args:
             name (str, optional):
@@ -416,8 +416,8 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
             ID (str, optional):
                 Target facility ID.
                 Defaults to None.
-            factory_id (str, optional):
-                Target facility factory_id.
+            workplace_id (str, optional):
+                Target facility workplace_id.
                 Defaults to None.
             cost_per_time (float, optional):
                 Target facility cost_per_time.
@@ -448,11 +448,11 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
             List[BaseFacility]: List of BaseFacility.
         """
         facility_list = []
-        for factory in self.factory_list:
-            facility_list = facility_list + factory.get_facility_list(
+        for workplace in self.workplace_list:
+            facility_list = facility_list + workplace.get_facility_list(
                 name=name,
                 ID=ID,
-                factory_id=factory_id,
+                workplace_id=workplace_id,
                 cost_per_time=cost_per_time,
                 solo_working=solo_working,
                 workamount_skill_mean_map=workamount_skill_mean_map,
@@ -471,7 +471,7 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
         If `log_info` is True, the following attributes are initialized.
           - cost_list
 
-        BaseTeam in `team_list` and BaseFactory in `factory_list` are also initialized by this function.
+        BaseTeam in `team_list` and BaseWorkplace in `workplace_list` are also initialized by this function.
 
         Args:
             state_info (bool):
@@ -485,8 +485,8 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
             self.cost_list = []
         for team in self.team_list:
             team.initialize(state_info=state_info, log_info=log_info)
-        for factory in self.factory_list:
-            factory.initialize(state_info=state_info, log_info=log_info)
+        for workplace in self.workplace_list:
+            workplace.initialize(state_info=state_info, log_info=log_info)
 
     def reverse_log_information(self):
         """
@@ -495,8 +495,8 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
         self.cost_list = self.cost_list[::-1]
         for team in self.team_list:
             team.reverse_log_information()
-        for factory in self.factory_list:
-            factory.reverse_log_information()
+        for workplace in self.workplace_list:
+            workplace.reverse_log_information()
 
     def add_labor_cost(
         self,
@@ -530,8 +530,8 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
                 only_working=only_working,
                 add_zero_to_all_workers=add_zero_to_all_workers,
             )
-        for factory in self.factory_list:
-            cost_this_time += factory.add_labor_cost(
+        for workplace in self.workplace_list:
+            cost_this_time += workplace.add_labor_cost(
                 only_working=only_working,
                 add_zero_to_all_facilities=add_zero_to_all_facilities,
             )
@@ -545,22 +545,20 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
         for team in self.team_list:
             team.record_assigned_task_id()
             team.record_all_worker_state()
-        for factory in self.factory_list:
-            factory.record_assigned_task_id()
-            factory.record_placed_component_id()
-            factory.record_all_facility_state()
+        for workplace in self.workplace_list:
+            workplace.record_assigned_task_id()
+            workplace.record_placed_component_id()
+            workplace.record_all_facility_state()
 
     def create_simple_gantt(
         self,
-        target_start_time=None,
-        target_finish_time=None,
         finish_margin=1.0,
         view_ready=False,
         view_workers=True,
         view_facilities=True,
         team_color="#0099FF",
         worker_color="#D9E5FF",
-        factory_color="#0099FF",
+        workplace_color="#0099FF",
         facility_color="#D9E5FF",
         ready_color="#C0C0C0",
         figsize=[6.4, 4.8],
@@ -574,12 +572,6 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
         This method will be used after simulation.
 
         Args:
-            target_start_time (int, optional):
-                Start time of target range of visualizing gant chart.
-                Defaults to None.
-            target_finish_time (int, optional):
-                Finish time of target range of visualizing gant chart.
-                Defaults to None.
             finish_margin (float, optional):
                 Margin of finish time in Gantt chart.
                 Defaults to 1.0.
@@ -595,7 +587,7 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
             worker_color (str, optional):
                 Node color setting information.
                 Defaults to "#D9E5FF".
-            factory_color (str, optional):
+            workplace_color (str, optional):
                 Node color setting information.
                 Defaults to "#0099FF".
             facility_color (str, optional):
@@ -633,10 +625,10 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
                     target_worker_list.append(worker)
                     yticklabels.append(team.name + ":" + worker.name)
         if view_facilities:
-            for factory in self.factory_list:
-                for facility in factory.facility_list:
+            for workplace in self.workplace_list:
+                for facility in workplace.facility_list:
                     target_facility_list.append(facility)
-                    yticklabels.append(factory.name + ":" + facility.name)
+                    yticklabels.append(workplace.name + ":" + facility.name)
         yticks = [
             10 * (n + 1)
             for n in range(len(target_worker_list) + len(target_facility_list))
@@ -683,7 +675,7 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
 
         if save_fig_path is not None:
             plt.savefig(save_fig_path)
-
+        plt.close()
         return fig, gnt
 
     def create_data_for_gantt_plotly(
@@ -720,9 +712,9 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
                     view_ready=view_ready,
                 )
             )
-        for factory in self.factory_list:
+        for workplace in self.workplace_list:
             df.extend(
-                factory.create_data_for_gantt_plotly(
+                workplace.create_data_for_gantt_plotly(
                     init_datetime,
                     unit_timedelta,
                     finish_margin=finish_margin,
@@ -866,8 +858,8 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
         ]
         for team in self.team_list:
             data.append(go.Bar(name=team.name, x=x, y=team.cost_list))
-        for factory in self.factory_list:
-            data.append(go.Bar(name=factory.name, x=x, y=factory.cost_list))
+        for workplace in self.workplace_list:
+            data.append(go.Bar(name=workplace.name, x=x, y=workplace.cost_list))
         return data
 
     def create_cost_history_plotly(
@@ -961,21 +953,21 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
                     G.add_node(w)
                     G.add_edge(team, w)
 
-        # BaseFactory
+        # BaseWorkplace
         # 1. add all nodes
-        for factory in self.factory_list:
-            G.add_node(factory)
+        for workplace in self.workplace_list:
+            G.add_node(workplace)
 
         # 2. add all edges
-        for factory in self.factory_list:
-            if factory.parent_factory is not None:
-                G.add_edge(factory.parent_factory, factory)
+        for workplace in self.workplace_list:
+            if workplace.parent_workplace is not None:
+                G.add_edge(workplace.parent_workplace, workplace)
 
         if view_facilities:
-            for factory in self.factory_list:
-                for w in factory.facility_list:
+            for workplace in self.workplace_list:
+                for w in workplace.facility_list:
                     G.add_node(w)
-                    G.add_edge(factory, w)
+                    G.add_edge(workplace, w)
 
         return G
 
@@ -984,12 +976,11 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
         G=None,
         pos=None,
         arrows=True,
-        with_labels=True,
         view_workers=False,
         team_node_color="#0099FF",
         worker_node_color="#D9E5FF",
         view_facilities=False,
-        factory_node_color="#0099FF",
+        workplace_node_color="#0099FF",
         facility_node_color="#D9E5FF",
         figsize=[6.4, 4.8],
         dpi=100.0,
@@ -1009,9 +1000,6 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
             arrows (bool, optional):
                 Digraph or Graph(no arrows).
                 Defaults to True.
-            with_labels (bool, optional):
-                Label is describing or not.
-                Defaults to True.
             view_workers (bool, optional):
                 Including workers in networkx graph or not.
                 Default to False.
@@ -1024,7 +1012,7 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
             view_facilities (bool, optional):
                 Including facilities in networkx graph or not.
                 Default to False.
-            factory_node_color (str, optional):
+            workplace_node_color (str, optional):
                 Node color setting information.
                 Defaults to "#0099FF".
             facility_node_color (str, optional):
@@ -1045,7 +1033,7 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
             figure: Figure for a network
         """
 
-        plt.figure(figsize=figsize, dpi=dpi)
+        fig = plt.figure(figsize=figsize, dpi=dpi)
         G = (
             G
             if G is not None
@@ -1055,13 +1043,10 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
         )
         pos = pos if pos is not None else nx.spring_layout(G)
 
-        # nx.draw_networkx(G, pos=pos, arrows=arrows, with_labels=with_labels, **kwds)
-
         # team
         nx.draw_networkx_nodes(
             G,
             pos,
-            with_labels=with_labels,
             nodelist=self.team_list,
             node_color=team_node_color,
             # **kwds,
@@ -1076,32 +1061,29 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
             nx.draw_networkx_nodes(
                 G,
                 pos,
-                with_labels=with_labels,
                 nodelist=worker_list,
                 node_color=worker_node_color,
                 # **kwds,
             )
 
-        # factory
+        # workplace
         nx.draw_networkx_nodes(
             G,
             pos,
-            with_labels=with_labels,
-            nodelist=self.factory_list,
-            node_color=factory_node_color,
+            nodelist=self.workplace_list,
+            node_color=workplace_node_color,
             # **kwds,
         )
         # facility
         if view_facilities:
 
             facility_list = []
-            for factory in self.factory_list:
-                facility_list.extend(factory.facility_list)
+            for workplace in self.workplace_list:
+                facility_list.extend(workplace.facility_list)
 
             nx.draw_networkx_nodes(
                 G,
                 pos,
-                with_labels=with_labels,
                 nodelist=facility_list,
                 node_color=facility_node_color,
                 # **kwds,
@@ -1112,6 +1094,8 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
         plt.axis("off")
         if save_fig_path is not None:
             plt.savefig(save_fig_path)
+        plt.close()
+        return fig
 
     def get_node_and_edge_trace_for_plotly_network(
         self,
@@ -1121,7 +1105,7 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
         team_node_color="#0099FF",
         worker_node_color="#D9E5FF",
         view_workers=False,
-        factory_node_color="#0099FF",
+        workplace_node_color="#0099FF",
         facility_node_color="#D9E5FF",
         view_facilities=False,
     ):
@@ -1147,7 +1131,7 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
             view_workers (bool, optional):
                 Including workers in networkx graph or not.
                 Default to False.
-            factory_node_color (str, optional):
+            workplace_node_color (str, optional):
                 Node color setting information.
                 Defaults to "#0099FF".
             facility_node_color (str, optional):
@@ -1160,7 +1144,7 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
         Returns:
             team_node_trace: Team Node information of plotly network.
             worker_node_trace: Worker Node information of plotly network.
-            factory_node_trace: Factory Node information of plotly network.
+            workplace_node_trace: Workplace Node information of plotly network.
             facility_node_trace: Facility Node information of plotly network.
             edge_trace: Edge information of plotly network.
         """
@@ -1196,14 +1180,14 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
                 size=node_size,
             ),
         )
-        factory_node_trace = go.Scatter(
+        workplace_node_trace = go.Scatter(
             x=[],
             y=[],
             text=[],
             mode="markers",
             hoverinfo="text",
             marker=dict(
-                color=factory_node_color,
+                color=workplace_node_color,
                 size=node_size,
             ),
         )
@@ -1225,10 +1209,10 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
                 team_node_trace["x"] = team_node_trace["x"] + (x,)
                 team_node_trace["y"] = team_node_trace["y"] + (y,)
                 team_node_trace["text"] = team_node_trace["text"] + (node,)
-            elif isinstance(node, BaseFactory):
-                factory_node_trace["x"] = factory_node_trace["x"] + (x,)
-                factory_node_trace["y"] = factory_node_trace["y"] + (y,)
-                factory_node_trace["text"] = factory_node_trace["text"] + (node,)
+            elif isinstance(node, BaseWorkplace):
+                workplace_node_trace["x"] = workplace_node_trace["x"] + (x,)
+                workplace_node_trace["y"] = workplace_node_trace["y"] + (y,)
+                workplace_node_trace["text"] = workplace_node_trace["text"] + (node,)
             elif isinstance(node, BaseFacility):
                 facility_node_trace["x"] = facility_node_trace["x"] + (x,)
                 facility_node_trace["y"] = facility_node_trace["y"] + (y,)
@@ -1253,7 +1237,7 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
         return (
             team_node_trace,
             worker_node_trace,
-            factory_node_trace,
+            workplace_node_trace,
             facility_node_trace,
             edge_trace,
         )
@@ -1267,7 +1251,7 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
         team_node_color="#0099FF",
         worker_node_color="#D9E5FF",
         view_workers=False,
-        factory_node_color="#0099FF",
+        workplace_node_color="#0099FF",
         facility_node_color="#D9E5FF",
         view_facilities=False,
         save_fig_path=None,
@@ -1297,7 +1281,7 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
             view_workers (bool, optional):
                 Including workers in networkx graph or not.
                 Default to False.
-            factory_node_color (str, optional):
+            workplace_node_color (str, optional):
                 Node color setting information.
                 Defaults to "#0099FF".
             facility_node_color (str, optional):
@@ -1328,7 +1312,7 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
         (
             team_node_trace,
             worker_node_trace,
-            factory_node_trace,
+            workplace_node_trace,
             facility_node_trace,
             edge_trace,
         ) = self.get_node_and_edge_trace_for_plotly_network(
@@ -1338,7 +1322,7 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
             team_node_color=team_node_color,
             worker_node_color=worker_node_color,
             view_workers=view_workers,
-            factory_node_color=factory_node_color,
+            workplace_node_color=workplace_node_color,
             facility_node_color=facility_node_color,
             view_facilities=view_facilities,
         )
@@ -1347,7 +1331,7 @@ class BaseOrganization(object, metaclass=abc.ABCMeta):
                 edge_trace,
                 team_node_trace,
                 worker_node_trace,
-                factory_node_trace,
+                workplace_node_trace,
                 facility_node_trace,
             ],
             layout=go.Layout(
