@@ -93,8 +93,8 @@ class BaseProduct(object, metaclass=abc.ABCMeta):
                 state_record_list=[
                     BaseComponentState(num) for num in j["state_record_list"]
                 ],
-                placed_factory=j["placed_factory"],
-                placed_factory_id_record=j["placed_factory_id_record"],
+                placed_workplace=j["placed_workplace"],
+                placed_workplace_id_record=j["placed_workplace_id_record"],
             )
             for j in j_list
         ]
@@ -206,8 +206,8 @@ class BaseProduct(object, metaclass=abc.ABCMeta):
         child_component_list=None,
         targeted_task_list=None,
         space_size=None,
-        placed_factory=None,
-        placed_factory_id_record=None,
+        placed_workplace=None,
+        placed_workplace_id_record=None,
     ):
         """
         Get component list by using search conditions related to BaseComponent parameter.
@@ -232,11 +232,11 @@ class BaseProduct(object, metaclass=abc.ABCMeta):
             space_size (float, optional):
                 Target component space_size.
                 Default to None.
-            placed_factory (BaseFactory, optional):
-                Target component placed_factory.
+            placed_workplace (BaseWorkplace, optional):
+                Target component placed_workplace.
                 Default to None.
-            placed_factory_id_record (List[str], optional):
-                Target component placed_factory_id_record.
+            placed_workplace_id_record (List[str], optional):
+                Target component placed_workplace_id_record.
                 Default to None.
         Returns:
             List[BaseComponent]: List of BaseComponent.
@@ -280,18 +280,18 @@ class BaseProduct(object, metaclass=abc.ABCMeta):
                     lambda component: component.space_size == space_size, component_list
                 )
             )
-        if placed_factory is not None:
+        if placed_workplace is not None:
             component_list = list(
                 filter(
-                    lambda component: component.placed_factory == placed_factory,
+                    lambda component: component.placed_workplace == placed_workplace,
                     component_list,
                 )
             )
-        if placed_factory_id_record is not None:
+        if placed_workplace_id_record is not None:
             component_list = list(
                 filter(
-                    lambda component: component.placed_factory_id_record
-                    == placed_factory_id_record,
+                    lambda component: component.placed_workplace_id_record
+                    == placed_workplace_id_record,
                     component_list,
                 )
             )
@@ -299,10 +299,10 @@ class BaseProduct(object, metaclass=abc.ABCMeta):
 
     def record(self):
         """
-        Record placed factory id in this time.
+        Record placed workplace id in this time.
         """
         for c in self.component_list:
-            c.record_placed_factory_id()
+            c.record_placed_workplace_id()
             c.record_state()
 
     def check_state(self):
@@ -312,16 +312,16 @@ class BaseProduct(object, metaclass=abc.ABCMeta):
         for c in self.component_list:
             c.check_state()
 
-    def check_removing_placed_factory(self, print_debug=False, log_txt=[]):
+    def check_removing_placed_workplace(self, print_debug=False, log_txt=[]):
         """
-        Check removing this product from placed_factory or not.
+        Check removing this product from placed_workplace or not.
         If all tasks of this product is finished, this product will be removed automatically.
         """
         top_component_list = list(
             filter(lambda c: len(c.parent_component_list) == 0, self.component_list)
         )
 
-        removing_placed_factory_component = []
+        removing_placed_workplace_component = []
         for c in top_component_list:
             all_finished_flag = all(
                 map(
@@ -329,27 +329,25 @@ class BaseProduct(object, metaclass=abc.ABCMeta):
                     c.targeted_task_list,
                 )
             )
-            if all_finished_flag and c.placed_factory is not None:
-                removing_placed_factory_component.append(c)
+            if all_finished_flag and c.placed_workplace is not None:
+                removing_placed_workplace_component.append(c)
 
-        for c in removing_placed_factory_component:
+        for c in removing_placed_workplace_component:
             if print_debug:
                 print(
                     "REMOVE ",
                     c.name,
                     " from ",
-                    c.placed_factory.name,
+                    c.placed_workplace.name,
                 )
             log_txt.append(
-                "REMOVE " + c.name + " from " + c.placed_factory.name,
+                "REMOVE " + c.name + " from " + c.placed_workplace.name,
             )
-            c.placed_factory.remove_placed_component(c)
-            c.set_placed_factory(None)
+            c.placed_workplace.remove_placed_component(c)
+            c.set_placed_workplace(None)
 
     def create_simple_gantt(
         self,
-        target_start_time=None,
-        target_finish_time=None,
         finish_margin=1.0,
         view_ready=True,
         component_color="#FF6600",
@@ -364,12 +362,6 @@ class BaseProduct(object, metaclass=abc.ABCMeta):
         This method will be used after simulation.
 
         Args:
-            target_start_time (int, optional):
-                Start time of target range of visualizing gant chart.
-                Defaults to None.
-            target_finish_time (int, optional):
-                Finish time of target range of visualizing gant chart.
-                Defaults to None.
             finish_margin (float, optional):
                 Margin of finish time in Gantt chart.
                 Defaults to 1.0.
@@ -424,7 +416,7 @@ class BaseProduct(object, metaclass=abc.ABCMeta):
 
         if save_fig_path is not None:
             plt.savefig(save_fig_path)
-
+        plt.close()
         return fig, gnt
 
     def create_data_for_gantt_plotly(
@@ -599,7 +591,6 @@ class BaseProduct(object, metaclass=abc.ABCMeta):
         G=None,
         pos=None,
         arrows=True,
-        with_labels=True,
         component_node_color="#FF6600",
         figsize=[6.4, 4.8],
         dpi=100.0,
@@ -619,9 +610,6 @@ class BaseProduct(object, metaclass=abc.ABCMeta):
             arrows (bool, optional):
                 Digraph or Graph(no arrows).
                 Defaults to True.
-            with_labels (bool, optional):
-                Label is describing or not.
-                Defaults to True.
             component_node_color (str, optional):
                 Node color setting information.
                 Defaults to "#FF6600".
@@ -646,13 +634,13 @@ class BaseProduct(object, metaclass=abc.ABCMeta):
             G,
             pos=pos,
             arrows=arrows,
-            with_labels=with_labels,
             node_color=component_node_color,
             **kwds,
         )
         plt.axis("off")
         if save_fig_path is not None:
             plt.savefig(save_fig_path)
+        plt.close()
         return r_nx
 
     def get_node_and_edge_trace_for_plotly_network(
