@@ -141,7 +141,7 @@ class BaseTeam(object, metaclass=abc.ABCMeta):
 
         Args:
             worker (BaseWorker):
-                Worker which is added to this factory
+                Worker which is added to this workplace
         """
         worker.team_id = self.ID
         self.worker_list.append(worker)
@@ -347,8 +347,8 @@ class BaseTeam(object, metaclass=abc.ABCMeta):
             ID (str, optional):
                 Target worker ID.
                 Defaults to None.
-            factory_id (str, optional):
-                Target worker factory_id.
+            workplace_id (str, optional):
+                Target worker workplace_id.
                 Defaults to None.
             cost_per_time (float, optional):
                 Target worker cost_per_time.
@@ -437,8 +437,6 @@ class BaseTeam(object, metaclass=abc.ABCMeta):
 
     def create_simple_gantt(
         self,
-        target_start_time=None,
-        target_finish_time=None,
         finish_margin=1.0,
         view_ready=False,
         worker_color="#D9E5FF",
@@ -453,12 +451,6 @@ class BaseTeam(object, metaclass=abc.ABCMeta):
         This method will be used after simulation.
 
         Args:
-            target_start_time (int, optional):
-                Start time of target range of visualizing gant chart.
-                Defaults to None.
-            target_finish_time (int, optional):
-                Finish time of target range of visualizing gant chart.
-                Defaults to None.
             finish_margin (float, optional):
                 Margin of finish time in Gantt chart.
                 Defaults to 1.0.
@@ -522,7 +514,7 @@ class BaseTeam(object, metaclass=abc.ABCMeta):
             )
         if save_fig_path is not None:
             plt.savefig(save_fig_path)
-
+        plt.close()
         return fig, gnt
 
     def create_data_for_gantt_plotly(
