@@ -26,9 +26,9 @@ class BaseWorker(BaseResource):
             Basic parameter.
             ID will be defined automatically.
             Defaults to None.
-        factory_id (str, optional):
+        workplace_id (str, optional):
             Basic parameter.
-            Factory ID will be defined automatically on adding factory.
+            Workplace ID will be defined automatically on adding workplace.
             Defaults to None.
         cost_per_time (float, optional):
             Basic parameter.
