@@ -93,7 +93,7 @@ class BaseWorkflow(object, metaclass=abc.ABCMeta):
                 input_task_list=j["input_task_list"],
                 output_task_list=j["output_task_list"],
                 allocated_team_list=j["allocated_team_list"],
-                allocated_factory_list=j["allocated_factory_list"],
+                allocated_workplace_list=j["allocated_workplace_list"],
                 need_facility=j["need_facility"],
                 target_component=j["target_component"],
                 default_progress=j["default_progress"],
@@ -216,7 +216,7 @@ class BaseWorkflow(object, metaclass=abc.ABCMeta):
         input_task_list=None,
         output_task_list=None,
         allocated_team_list=None,
-        allocated_factory_list=None,
+        allocated_workplace_list=None,
         need_facility=None,
         target_component=None,
         default_progress=None,
@@ -259,8 +259,8 @@ class BaseWorkflow(object, metaclass=abc.ABCMeta):
             allocated_team_list (List[BaseTeam], optional):
                 Target task allocated_team_list
                 Defaults to None.
-            allocated_factory_list (List[BaseFactory], optional):
-                Target task allocated_factory_list
+            allocated_workplace_list (List[BaseWorkplace], optional):
+                Target task allocated_workplace_list
                 Defaults to None.
             need_facility (bool, optional):
                 Target task need_facility
@@ -345,10 +345,11 @@ class BaseWorkflow(object, metaclass=abc.ABCMeta):
                     task_list,
                 )
             )
-        if allocated_factory_list is not None:
+        if allocated_workplace_list is not None:
             task_list = list(
                 filter(
-                    lambda task: task.allocated_factory_list == allocated_factory_list,
+                    lambda task: task.allocated_workplace_list
+                    == allocated_workplace_list,
                     task_list,
                 )
             )
@@ -791,8 +792,6 @@ class BaseWorkflow(object, metaclass=abc.ABCMeta):
 
     def create_simple_gantt(
         self,
-        target_start_time=None,
-        target_finish_time=None,
         finish_margin=1.0,
         view_auto_task=False,
         view_ready=False,
@@ -810,12 +809,6 @@ class BaseWorkflow(object, metaclass=abc.ABCMeta):
         This method will be used after simulation.
 
         Args:
-            target_start_time (int, optional):
-                Start time of target range of visualizing gant chart.
-                Defaults to None.
-            target_finish_time (int, optional):
-                Finish time of target range of visualizing gant chart.
-                Defaults to None.
             finish_margin (float, optional):
                 Margin of finish time in Gantt chart.
                 Defaults to 1.0.
@@ -888,7 +881,7 @@ class BaseWorkflow(object, metaclass=abc.ABCMeta):
 
         if save_fig_path is not None:
             plt.savefig(save_fig_path)
-
+        plt.close()
         return fig, gnt
 
     def create_data_for_gantt_plotly(
@@ -1063,7 +1056,6 @@ class BaseWorkflow(object, metaclass=abc.ABCMeta):
         G=None,
         pos=None,
         arrows=True,
-        with_labels=True,
         task_node_color="#00EE00",
         auto_task_node_color="#005500",
         figsize=[6.4, 4.8],
@@ -1084,9 +1076,6 @@ class BaseWorkflow(object, metaclass=abc.ABCMeta):
             arrows (bool, optional):
                 Digraph or Graph(no arrows).
                 Defaults to True.
-            with_labels (bool, optional):
-                Label is describing or not.
-                Defaults to True.
             task_node_color (str, optional):
                 Node color setting information.
                 Defaults to "#00EE00".
@@ -1107,17 +1096,15 @@ class BaseWorkflow(object, metaclass=abc.ABCMeta):
         Returns:
             figure: Figure for a network
         """
-        plt.figure(figsize=figsize, dpi=dpi)
+        fig = plt.figure(figsize=figsize, dpi=dpi)
         G = G if G is not None else self.get_networkx_graph()
         pos = pos if pos is not None else nx.spring_layout(G)
-        # nx.draw_networkx(G, pos=pos, arrows=arrows, with_labels=with_labels, **kwds)
 
         # normal task
         normal_task_list = [task for task in self.task_list if not task.auto_task]
         nx.draw_networkx_nodes(
             G,
             pos,
-            with_labels=with_labels,
             nodelist=normal_task_list,
             node_color=task_node_color,
             # **kwds,
@@ -1128,7 +1115,6 @@ class BaseWorkflow(object, metaclass=abc.ABCMeta):
         nx.draw_networkx_nodes(
             G,
             pos,
-            with_labels=with_labels,
             nodelist=auto_task_list,
             node_color=auto_task_node_color,
             # **kwds,
@@ -1139,6 +1125,8 @@ class BaseWorkflow(object, metaclass=abc.ABCMeta):
         plt.axis("off")
         if save_fig_path is not None:
             plt.savefig(save_fig_path)
+        plt.close()
+        return fig
 
     def get_node_and_edge_trace_for_plotly_network(
         self,
